==> rakudo_2020.12+dfsg.orig.tar.xz: rakudo-2020.12/IN-MEMORIAM.md <==
The people mentioned here have been contributors to the various stages of
the development of the Raku Programming Language, but unfortunately have
departed this existence.  We thank them for their contributions and hope
to keep their memory alive here, as well as other places.

Jonathan Scott Duff (perlpilot)
-------------------------------
In the early days of the Rakudo implementation, Jonathan Scott Duff
implemented many of the NQP and Raku features that we take for granted
now.  In later years, he kept a very observant eye on developments in
the Rakudo and NQP code.

From the obituary at: https://www.legacy.com/obituaries/caller/obituary.aspx?n=jonathan-scott-duff&pid=191217621

> Born in Baton Rouge, La. and raised in Corpus Christi, TX, he passed away at the age of 47 in his home in Fort Worth, TX on Friday, Dec. 28, 2018 after battling cancer.

> He was a beloved husband, father, and friend. He is survived by his devoted wife, Cynthia; four children, Jazmine, Christian, Camryn, and Joseph, all of Fort Worth, Tx; his loving mother, Linda T Duff of LaPlace, La.; brothers, Brian Duff of Corpus Christi, TX, and Allen Duff of LaPlace, La; and many nieces and nephews. He was preceded in death by his father, Grady W. Duff, Jr 'Dub'.

Jeff Goff (DrForr)
------------------
Ever since Jeff Goff got involved in the Perl community, he could be
found helping people. He was very active at events and conferences:
giving presentations, volunteering, and gaming with other attendees.

He also supported development as a release manager for the Parrot project.
Many have benefitted from his online presence, always ready to
help and answer questions.

From the obituary at: https://www.facebook.com/marcia.goff.5/posts/10213755697281665

> Jeffrey Michael Goff, 50, passed away March 13, 2020, while snorkeling with a group in the Bahamas. He was born Feb. 25, 1970, in Charleston, IL to Michael and Marcia Goff. He moved to Nebraska with his family in 1973. He graduated from Milford High School in 1988, and received his bachelor of science degree in computer science and mathematics from Buena Vista College (now University) in Storm Lake, Iowa, in 1992, where he was named the Outstanding Student in Computer Science.

> Throughout his career, Jeff worked as a senior computer programmer and engineer. He lived and worked in numerous cities in the United States and, for 10 years, lived and worked in Europe. He was often a presenter at international open source computer conferences. His passion was the continuing development and promotion of the Perl programming language. He loved to travel, experience new cultures and adventures, and challenge himself to learn new skills and develop new talents. Among his many hobbies were glassblowing, origami, juggling, photography, and writing articles and blogs to share with the Perl community.

> He is survived by his parents; his brother and sister-in-law, Brandon and Rebecca Goff, St. Ignatius, MT; his aunt and uncle, Christine and Roger Sebby, Colorado Springs, CO; cousins Amber and Ed Shipp and family of Colorado Springs, and Chad and Renae Sebby and family of Olathe, KS; and many dear friends throughout the world.

Final words
-----------
If you have any suggestions for additions, changes or other comments,
please create an issue for it, or even better, a Pull Request, so that
we can give these people all the credit they deserve.

==> rakudo_2022.12.orig.tar.xz: rakudo-2022.12/IN-MEMORIAM.md <==
# In Memoriam

The people mentioned here have been contributors to the various stages of
the development of the Raku Programming Language, but unfortunately have
departed this existence.  We thank them for their contributions and hope
to keep their memory alive here, as well as in other places.

David H. Adler (dha)
--------------------
David had many hobbies, in which he all excelled (like knowledge about Monty
Python, Doctor Who, really, really bad movies, to name but a few of them).
The Perl / Raku community was only one of the communities he was part of.

David was involved in the very early Raku development process. More recently,
he was involved in documenting various features of the Raku Programming
Language.  Attending many Perl and related Open Source Conferences, he was
a familiar sight and a good person to spend time with. He is sorely missed.

See also:
- [Family memorial](https://www.dignitymemorial.com/obituaries/forest-hills-ny/david-adler-10451028)
- [FaceBook](https://www.facebook.com/ginarsnape/posts/10227412275758366)
- [/r/perl](https://www.reddit.com/r/perl/comments/qvxdun/dha_rip/)
- [blogs.perl.org](http://blogs.perl.org/users/damian_conway/2021/11/vale-david.html)
- [Rakudo Weekly](https://rakudoweekly.blog/2021/11/23/2021-47-david-h-adler-rip/)

Jonathan Scott Duff (perlpilot)
-------------------------------
In the early days of the Rakudo implementation, Jonathan Scott Duff
implemented many of the NQP and Raku features that we take for granted
now.  In later years, he kept a very observant eye on developments in
the Rakudo and NQP code.

From the obituary at: https://www.legacy.com/obituaries/caller/obituary.aspx?n=jonathan-scott-duff&pid=191217621

> Born in Baton Rouge, La. and raised in Corpus Christi, TX, he passed away at the age of 47 in his home in Fort Worth, TX on Friday, Dec. 28, 2018 after battling cancer.

> He was a beloved husband, father, and friend. He is survived by his devoted wife, Cynthia; four children, Jazmine, Christian, Camryn, and Joseph, all of Fort Worth, Tx; his loving mother, Linda T Duff of LaPlace, La.; brothers, Brian Duff of Corpus Christi, TX, and Allen Duff of LaPlace, La; and many nieces and nephews. He was preceded in death by his father, Grady W. Duff, Jr 'Dub'.

Jeff Goff (DrForr)
------------------
Ever since Jeff Goff got involved in the Perl community, he could be
found helping people. He was very active at events and conferences:
giving presentations, volunteering, and gaming with other attendees.

He also supported development as a release manager for the Parrot project.
Many have benefitted from his online presence, always ready to
help and answer questions.

From the obituary at: https://www.facebook.com/marcia.goff.5/posts/10213755697281665

> Jeffrey Michael Goff, 50, passed away March 13, 2020, while snorkeling with a group in the Bahamas. He was born Feb. 25, 1970, in Charleston, IL to Michael and Marcia Goff. He moved to Nebraska with his family in 1973. He graduated from Milford High School in 1988, and received his bachelor of science degree in computer science and mathematics from Buena Vista College (now University) in Storm Lake, Iowa, in 1992, where he was named the Outstanding Student in Computer Science.

> Throughout his career, Jeff worked as a senior computer programmer and engineer. He lived and worked in numerous cities in the United States and, for 10 years, lived and worked in Europe. He was often a presenter at international open source computer conferences. His passion was the continuing development and promotion of the Perl programming language. He loved to travel, experience new cultures and adventures, and challenge himself to learn new skills and develop new talents. Among his many hobbies were glassblowing, origami, juggling, photography, and writing articles and blogs to share with the Perl community.

> He is survived by his parents; his brother and sister-in-law, Brandon and Rebecca Goff, St. Ignatius, MT; his aunt and uncle, Christine and Roger Sebby, Colorado Springs, CO; cousins Amber and Ed Shipp and family of Colorado Springs, and Chad and Renae Sebby and family of Olathe, KS; and many dear friends throughout the world.

Robert Lemmen (ROBERTLE)
------------------------
In June 2020, Robert Lemmen passed away after a serious illness.  Among other contributions, he packaged modules for Raku (Perl6 at that time) and helped other contributors to get involved in the Raku Team.  Robert Lemmen further contributed to MoarVM, nqp and the Raku documentation, as well as being the author of several ecosystem modules.

From the obituary at: https://www.debian.org/News/2021/20210812

Final words
-----------
If you have any suggestions for additions, changes or other comments,
please create an issue for it, or even better, a Pull Request, so that
we can give these people all the credit they deserve.
